;; Generated package description from async.el  -*- no-byte-compile: t -*-
(define-package "async" "1.9.7.0.20231122.210110" "Asynchronous processing in Emacs" '((emacs "24.4")) :commit "b4b5a7eedc30122aebf84ee950dc84da444e8953" :authors '(("John Wiegley" . "jwiegley@gmail.com")) :maintainer '("Thierry Volpiatto" . "thievol@posteo.net") :keywords '("async") :url "https://github.com/jwiegley/emacs-async")
